@@ -70,40 +70,40 @@ class Validators:
 class Serializer:
     """This class serializes data."""
 
-    def __init__(self, response, status_code, message, e):
+    def __init__(self, response=[], status_code=200, message="OK", e="Error"):
         """Constructor."""
         self.response = response
         self.status_code = status_code
         self.message = message
         self.e = e
 
-    def serialize(self, response, status_code, message):
+    def serialize(self):
         """Serializes data output."""
         if self.status_code in (400, 401, 403, 404, 405, 500):
             return json.dumps({
-                "status": status_code,
-                "message": message,
-                "error": response
-            }), status_code
+                "status": self.status_code,
+                "message": self.message,
+                "error": self.response
+            }), self.status_code
         return json.dumps({
-            "status": status_code,
-            "message": message,
-            "data": response
-        }), status_code
+            "status": self.status_code,
+            "message": self.message,
+            "data": self.response
+        }), self.status_code
 
-    def raise_error(self, status_code, message):
+    def raise_error(self):
         """Display error message."""
         return json.dumps({
-            "status": status_code,
-            "message": message
-        }), status_code
+            "status": self.status_code,
+            "message": self.message
+        }), self.status_code
 
-    def on_success(self, status_code, message):
+    def on_success(self):
         """Display success message."""
         return json.dumps({
-            "status": status_code,
-            "message": message
-        }), status_code
+            "status": self.status_code,
+            "message": self.message
+        }), self.status_code
 
     def bad_request(self):
         """Capture bad request error."""
